==> nextcloud-22.2.10.tgz: nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "Home" : "Initio",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu configurationes ha essite actualisate.",
    "Settings have been updated." : "Configurationes actualisate",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "Hello %s," : "Salute %s,",
    "There was some activity at %s" : "Il habeva alcun activitate in %s",
    "Mail" : "Posta",
    "Activity" : "Activitate",
    "Notifications" : "Notificationes",
    "No activity yet" : "Nulle activitate ancora",
    "Activities" : "Activitates",
    "No activities" : "Nulle activitates",
    "Activity feed" : "Syndication de activitate",
    "Default settings" : "Configurationes predefinite",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "Settings" : "Configurationes",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Nulle altere eventos a cargar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "Home" : "Initio",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu configurationes ha essite actualisate.",
    "Settings have been updated." : "Configurationes actualisate",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "Hello %s," : "Salute %s,",
    "There was some activity at %s" : "Il habeva alcun activitate in %s",
    "Mail" : "Posta",
    "Activity" : "Activitate",
    "Notifications" : "Notificationes",
    "Send email" : "Inviar message de e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "No activity yet" : "Nulle activitate ancora",
    "Activities" : "Activitates",
    "No activities" : "Nulle activitates",
    "Default settings" : "Configurationes predefinite",
    "Activity feed" : "Syndication de activitate",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Nulle altere eventos a cargar",
    "Settings" : "Configurationes"
},
"nplurals=2; plural=(n != 1);");
